@@ -23,7 +23,7 @@ from aliyunsdklive.endpoint import endpoint_data
 class AddLiveAppRecordConfigRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'live', '2016-11-01', 'AddLiveAppRecordConfig')
+		RpcRequest.__init__(self, 'live', '2016-11-01', 'AddLiveAppRecordConfig','live')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -92,7 +92,7 @@ class AddLiveAppRecordConfigRequest(RpcRequest):
 		self.add_query_param('OwnerId',OwnerId)
 
 	def get_RecordFormats(self):
-		return self.get_query_params().get('RecordFormats')
+		return self.get_query_params().get('RecordFormat')
 
 	def set_RecordFormats(self, RecordFormats):
 		for depth1 in range(len(RecordFormats)):
